@@ -19,15 +19,9 @@
 #if	HAVE_UTIME_H
 #include	<utime.h>
 #endif
-#if TIME_WITH_SYS_TIME
-#include	<sys/time.h>
 #include	<time.h>
-#else
 #if HAVE_SYS_TIME_H
 #include	<sys/time.h>
-#else
-#include	<time.h>
-#endif
 #endif
 #if HAVE_LOCALE_H
 #include	<locale.h>
@@ -354,7 +348,7 @@ static void list_callback(const char *f, void *vp)
 	struct list_callback_utf8 *utf8=(struct list_callback_utf8 *)vp;
 	maildir_aclt_list l;
 
-	char **fn=maildir_smapfn_fromutf7(f);
+	char **fn=maildir_smapfn_fromutf8(f);
 
 	if (!fn)
 	{
@@ -687,6 +681,7 @@ static void do_listcmd(struct list_hier **head,
 					}
 
 					maildir_aclt_list_destroy(&aclt_list);
+					maildir_info_destroy(&minfo);
 				}
 				else
 				{
@@ -3141,6 +3136,7 @@ static int dosetdeleteacl(void *cb_arg, int dodelete)
 		maildir_aclt_list_destroy(&aclt_list);
 		return 0;
 	}
+	free(path);
 
 	cnt=0;
 	maildir_aclt_list_enum(&aclt_list,
@@ -3215,6 +3211,7 @@ void smap()
 
 	char rights_buf[40];
 
+	enabled_utf8=1;
 	imapscan_init(&current_maildir_info);
 	memset(&add_flags, 0, sizeof(add_flags));
 
@@ -3244,6 +3241,7 @@ void smap()
 			while (*(p=getword(&ptr)))
 			{
 				char *q=strchr(p, '=');
+				char *comma=q;
 
 				if (q)
 					*q++=0;
@@ -3334,7 +3332,7 @@ void smap()
 				{
 					memset(&add_flags, 0,
 					       sizeof(add_flags));
-					*--q='=';
+					*(q=comma)='=';
 					parseflags(q, &add_flags);
 
 					if (strchr(rights_buf,
@@ -3369,7 +3367,7 @@ void smap()
 						write_error_exit(0);
 					}
 
-					*--q='=';
+					*(q=comma)='=';
 					parsekeywords(q, &addKeywords);
 					okmsg="KEYWORDS set";
 				}
@@ -3759,6 +3757,7 @@ void smap()
 
 			if (strchr(rights_buf, ACL_LOOKUP[0]) == NULL)
 			{
+				free(t);
 				accessdenied(ACL_LOOKUP);
 				continue;
 			}
@@ -3778,6 +3777,7 @@ void smap()
 
 				if (imapscan_maildir(infoptr, t, 1, 1, NULL))
 				{
+					free(t);
 					writes("-ERR Cannot read"
 					       " folder status: ");
 					writes(strerror(errno));
@@ -3785,6 +3785,7 @@ void smap()
 					continue;
 				}
 			}
+			free(t);
 
 			writes("* STATUS EXISTS=");
 			writen(infoptr->nmessages+infoptr->left_unseen);
@@ -3903,6 +3904,8 @@ void smap()
 				if (maildir_info_smap_find(&minfo, fn,
 							   getenv("AUTHENTICATED")) == 0)
 				{
+					maildir_smapfn_free(fn);
+
 					if (minfo.homedir && minfo.maildir)
 					{
 						maildir_aclt_list list;
@@ -3936,6 +3939,7 @@ void smap()
 						{
 							if (q)
 								free(q);
+							maildir_aclt_list_destroy(&list);
 							maildir_info_destroy(&minfo);
 							accessdenied(ACL_DELETEFOLDER);
 							continue;
@@ -3947,6 +3951,10 @@ void smap()
 					}
 					maildir_info_destroy(&minfo);
 				}
+				else
+				{
+					maildir_smapfn_free(fn);
+				}
 			}
 
 			if (t && current_mailbox &&
@@ -4073,6 +4081,8 @@ void smap()
 			{
 				writes("+OK Folder renamed.\n");
 			}
+			maildir_smapfn_free(fnsrc);
+			maildir_smapfn_free(fndst);
 			maildir_info_destroy(&msrc);
 			maildir_info_destroy(&mdst);
 			continue;
@@ -4214,9 +4224,7 @@ void smap()
 
 		if (strcmp(p, "IDLE") == 0)
 		{
-			if ((p=getenv("IMAP_ENHANCEDIDLE")) == NULL
-			    || !atoi(p)
-			    || imapenhancedidle())
+			if (imapenhancedidle())
 				imapidle();
 
 			read_timeout(60);
