@@ -22,7 +22,7 @@
 #include	<stdlib.h>
 #include	<ctype.h>
 #include	<netdb.h>
-#include	<idna.h>
+#include	<idn2.h>
 #if HAVE_DIRENT_H
 #include <dirent.h>
 #define NAMLEN(dirent) strlen((dirent)->d_name)
@@ -205,11 +205,11 @@ static int hostmatch(const struct tls_info *info, const char *domain)
 		}
 	}
 
-	if (idna_to_unicode_8z8z(verify_domain, &idn_domain1, 0)
+	if (idn2_to_unicode_8z8z(verify_domain, &idn_domain1, 0)
 	    != IDNA_SUCCESS)
 		idn_domain1=0;
 
-	if (idna_to_unicode_8z8z(p, &idn_domain2, 0)
+	if (idn2_to_unicode_8z8z(p, &idn_domain2, 0)
 	    != IDNA_SUCCESS)
 		idn_domain2=0;
 
@@ -413,6 +413,8 @@ static void load_dh_params(SSL_CTX *ctx, const char *filename,
 	if (*cert_file_flags)
 		return;
 
+	ERR_clear_error();
+
 	if ((bio=BIO_new_file(filename, "r")) != 0)
 	{
 #if HAVE_PEM_READ_BIO_PARAMETERS_EX
@@ -460,7 +462,12 @@ static void load_dh_params(SSL_CTX *ctx, const char *filename,
 
 			int err=ERR_peek_last_error();
 
-			if (ERR_GET_LIB(err) == ERR_LIB_PEM
+			if (err == 0)
+				/*
+				** No error, and no parameters. Fail.
+				*/
+				;
+			else if (ERR_GET_LIB(err) == ERR_LIB_PEM
 			    && ERR_GET_REASON(err) == PEM_R_NO_START_LINE)
 			{
 				ERR_clear_error();
@@ -1558,7 +1565,7 @@ SSL *tls_connect(SSL_CTX *ctx, int fd)
 
 		if (info->peer_verify_domain)
 		{
-			if (idna_to_unicode_8z8z(info->peer_verify_domain,
+			if (idn2_to_unicode_8z8z(info->peer_verify_domain,
 						 &idn_domain1, 0)
 			    != IDNA_SUCCESS)
 				idn_domain1=0;
